===============================
scikit-ci-addons
===============================

.. image:: https://readthedocs.org/projects/scikit-ci-addons/badge/?version=latest
    :target: http://scikit-ci-addons.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://ci.appveyor.com/api/projects/status/gr60jc9hkjlqoo4a?svg=true
    :target: https://ci.appveyor.com/project/scikit-build/scikit-ci-addons/branch/master

.. image:: https://circleci.com/gh/scikit-build/scikit-ci-addons/tree/master.svg?style=svg
    :target: https://circleci.com/gh/scikit-build/scikit-ci-addons/tree/master

.. image:: https://img.shields.io/travis/scikit-build/scikit-ci-addons.svg?maxAge=2592000
    :target: https://travis-ci.org/scikit-build/scikit-ci-addons

.. image:: https://codecov.io/gh/scikit-build/scikit-ci-addons/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/scikit-build/scikit-ci-addons

scikit-ci-addons is a command line tool and a set of scripts useful to install
prerequisites for building Python extension on CI services.

* Free software: Apache Software license
* Documentation: http://scikit-ci-addons.readthedocs.org
* Source code: https://github.com/scikit-build/scikit-addons
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build
